// all supported hooks

  def (INIT)
  def (DESTROY)
  def (RESET)
  def (START)
  def (CHILD_START)
  def (CHILD_EXIT)

  def (SEL_BEGIN)
  def (SEL_EXTEND)
  def (SEL_MAKE)
  def (SEL_GRAB)

  def (SEL_CLICK)

  def (VIEW_CHANGE)
  def (SCROLL_BACK)
  def (LINE_UPDATE)
  def (ADD_LINES)
  def (OSC_SEQ)
  def (TT_WRITE)

  def (REFRESH_BEGIN)
  def (REFRESH_END)

  def (USER_COMMAND)

  def (X_EVENT)
  def (FOCUS_IN)
  def (FOCUS_OUT)
  def (KEY_PRESS)
  def (KEY_RELEASE)
  def (BUTTON_PRESS)
  def (BUTTON_RELEASE)
  def (MOTION_NOTIFY)
  def (MAP_NOTIFY)
  def (UNMAP_NOTIFY)
  def (CONFIGURE_NOTIFY)
  def (CLIENT_MESSAGE)
  def (WM_DELETE_WINDOW)
  def (WM_PROTOCOLS)
  def (PROPERTY_NOTIFY)
  def (RESIZE_ALL_WINDOWS)

  def (XIM_PREEDIT_START)
  def (XIM_PREEDIT_DONE)
  def (XIM_PREEDIT_DRAW)
  def (XIM_PREEDIT_CARET)

  def (CUSTOM_REND) // hovering over custom rendition, generate enter/leave maybe?

